@@ -15,7 +15,7 @@ from domonic.html import *
 from domonic.decorators import silence
 
 
-class domonicTestCase(unittest.TestCase):
+class TestCase(unittest.TestCase):
 
     def test_hello_world(self):
         assert str(html(body(h1('Hello World!')))) == \
