@@ -15,7 +15,7 @@ from domonic.mathml import *
 from domonic.decorators import silence
 
 
-class domonicTestCase(unittest.TestCase):
+class TestCase(unittest.TestCase):
 
     def test_mathml(self):
         somemath = math_(
